@@ -2,7 +2,7 @@ from .standard_functions import (
     latency, merge_signals, merge_filterbanks, pad_trim,
     fractional_delay, fractional_octave_frequencies, activity_detector, fade,
     ir_to_filter, normalize, true_peak_level, resample, load_pkl_object,
-    erb_frequencies, filter_to_ir, detrend
+    erb_frequencies, filter_to_ir, detrend, rms, CalibrationData,
 )
 from .classes import Filter, FilterBank, Signal, MultiBandSignal
 from . import transfer_functions
@@ -24,11 +24,11 @@ __all__ = [
     'resample', 'activity_detector', 'normalize',
     'fractional_delay', 'true_peak_level', 'ir_to_filter', 'erb_frequencies',
     'load_pkl_object', 'fractional_octave_frequencies', 'filter_to_ir',
-    'detrend',
+    'detrend', 'rms', 'CalibrationData',
 
     # Modules
     'transfer_functions', 'distances', 'room_acoustics', 'plots', 'generators',
     'filterbanks', 'special', 'audio_io', 'beamforming',
 ]
 
-__version__ = '0.2.3'
+__version__ = '0.2.4'
