@@ -14,7 +14,7 @@ Here are contained some functions that are related to room acoustics.
 """
 from .room_acoustics import (reverb_time, find_modes, convolve_rir_on_signal,
                              find_ir_start, generate_synthetic_rir,
-                             ShoeboxRoom)
+                             ShoeboxRoom, descriptors)
 
 __all__ = [
     'reverb_time',
@@ -22,5 +22,6 @@ __all__ = [
     'convolve_rir_on_signal',
     'find_ir_start',
     'generate_synthetic_rir',
-    'ShoeboxRoom'
+    'ShoeboxRoom',
+    'descriptors'
 ]
